@@ -100,8 +100,8 @@ class Link:
             "namespace": "",
         },
     )
-    pose: "Link.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Link.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -225,7 +225,7 @@ class Link:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -272,8 +272,8 @@ class Link:
                 "namespace": "",
             },
         )
-        pose: "Link.Inertial.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.Inertial.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -350,7 +350,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -411,8 +411,8 @@ class Link:
                 "required": True,
             },
         )
-        pose: "Link.Projector.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.Projector.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -445,7 +445,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -554,8 +554,8 @@ class Link:
                 "required": True,
             },
         )
-        pose: "Link.AudioSource.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.AudioSource.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -594,7 +594,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -825,8 +825,8 @@ class Link:
                 "required": True,
             },
         )
-        pose: "Link.ParticleEmitter.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.ParticleEmitter.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -866,7 +866,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
